# Release History

All notable changes to this project will be documented in this file. This project follows [Semantic Versioning](https://semver.org/).

# 0.2.0 (2026-02-16)

## What's Changed
### 🛠 Enhancements made
* Memory parent class improvements by @colinfrisch in https://github.com/mesa/mesa-llm/pull/30
### 🐛 Bugs fixed
* Fix Ollama tool calling crash when system prompt is None by @februarysea in https://github.com/mesa/mesa-llm/pull/41
* fix: treat ollama_chat as ollama provider by @februarysea in https://github.com/mesa/mesa-llm/pull/43
* Fix prompt gestion by @colinfrisch in https://github.com/mesa/mesa-llm/pull/48
* add error handling to move one step tool by @apoorvasj in https://github.com/mesa/mesa-llm/pull/62
### 🔍 Examples updated
* Sugarscape g1mt by @sujalgawas in https://github.com/mesa/mesa-llm/pull/35
* feat: Add dialogue history context to negotiation agents by @Nithin9585 in https://github.com/mesa/mesa-llm/pull/56
### 📜 Documentation improvements
* update links for repository transfer by @wang-boyu in https://github.com/mesa/mesa-llm/pull/19
* docs: Add Google Gemini to supported LLMs in README by @sujalgawas in https://github.com/mesa/mesa-llm/pull/24
* Update organization name from `projectmesa` to `mesa` by @EwoutH in https://github.com/mesa/mesa-llm/pull/39
* Update contact email. by @jackiekazil in https://github.com/mesa/mesa-llm/pull/40
* docs: Add examples page and expand API documentation structure by @colinfrisch in https://github.com/mesa/mesa-llm/pull/33
* Add mesa-llm overview by @niteshver in https://github.com/mesa/mesa-llm/pull/60
* Add first mesa-llm model tutorial  by @niteshver in https://github.com/mesa/mesa-llm/pull/45
* add getting_started for mesa_llm by @niteshver in https://github.com/mesa/mesa-llm/pull/64
* Implemented API documentation using Sphinx by @pushpitkamboj in https://github.com/mesa/mesa-llm/pull/46
* docs: add sugarscrap model in example folder  by @niteshver in https://github.com/mesa/mesa-llm/pull/74
### 🔧 Maintenance
* test(reasoning): Add tests for Reasoning base class by @DipayanDasgupta in https://github.com/mesa/mesa-llm/pull/21
* Test episodic memory by @sujalgawas in https://github.com/mesa/mesa-llm/pull/26
* Test lt memory by @sujalgawas in https://github.com/mesa/mesa-llm/pull/27
* test: update module_llm tests for system prompt handling (None -> "") by @februarysea in https://github.com/mesa/mesa-llm/pull/44
* configure automatically generated release notes by @wang-boyu in https://github.com/mesa/mesa-llm/pull/72
### Other changes
* Fix and add dependencies by @colinfrisch in https://github.com/mesa/mesa-llm/pull/49

## New Contributors
* @DipayanDasgupta made their first contribution in https://github.com/mesa/mesa-llm/pull/21
* @sujalgawas made their first contribution in https://github.com/mesa/mesa-llm/pull/24
* @EwoutH made their first contribution in https://github.com/mesa/mesa-llm/pull/39
* @jackiekazil made their first contribution in https://github.com/mesa/mesa-llm/pull/40
* @februarysea made their first contribution in https://github.com/mesa/mesa-llm/pull/41
* @Nithin9585 made their first contribution in https://github.com/mesa/mesa-llm/pull/56
* @niteshver made their first contribution in https://github.com/mesa/mesa-llm/pull/60
* @apoorvasj made their first contribution in https://github.com/mesa/mesa-llm/pull/62
* @pushpitkamboj made their first contribution in https://github.com/mesa/mesa-llm/pull/46

**Full Changelog**: https://github.com/mesa/mesa-llm/compare/v0.1.1...v0.2.0

# 0.1.1 (2025-09-12)

## What's Changed
- First public release.
- Core repository structure and documentation.

**Full Changelog**: https://github.com/mesa/mesa-llm/compare/v0.0.2...v0.1.1
